@@ -1,5 +1,5 @@
 /* Quinn Diff, Determine which packages need recompiled for any given architecture */
-/* Copyright (C) 1997-1999, James Troup <james@nocrew.org> */
+/* Copyright (C) 1997-2001, James Troup <james@nocrew.org> */
 
 /* This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -19,7 +19,7 @@
 #ifndef __ARCH_SPECIFC_H__
 #define __ARCH_SPECIFC_H__
 
-#include "main.h"
+#include "common.h"
 
 void arch_specific_packages_ht_create (void);
 void arch_specific_packages_read (void);
