@@ -16,9 +16,16 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
+#ifndef __XMALLOC_H__
+#define __XMALLOC_H__
+
 #include <stdio.h>
 
 void *fixup_null_alloc (size_t n);
 void *xmalloc (size_t n);
 void *xcalloc (size_t n, size_t s);
 void *xrealloc (void *p, size_t n);
+#define xfree_if_non_null(p) if (p) { free (p); p = NULL; };
+#define xfree(p) free (p); p=NULL;
+
+#endif /* __XMALLOC_H__ */
